@@ -15,7 +15,7 @@ class KeyBindings(object):
 
     @property
     def line(self):
-        return self._cli_ref().line
+        return self.cli_ref().line
 
     def register_in_registry(self, registry):
         """
